@@ -20,11 +20,28 @@
 """Download posts and user metadata from the microblogging service Twitter."""
 
 
-from .twitterhistorydownloader import TwitterHistoryDownloader
+import argparse
 
 
 def main():
     """Download posts and user metadata from the microblogging service Twitter."""
+    argparser = argparse.ArgumentParser(prog="python -m twitterhistory")
+    argparser.add_argument(
+        "-c",
+        "--config",
+        help="""Use this config file (instead of the default location, see README)""",
+        default=None
+    )
+    args = argparser.parse_args()
+
+    # because Config is a pseudo-singleton, we have to import it only here (once
+    # we know a possible different configuration file path)
+    # We also need to explicitely create a Config() because importing
+    # TwitterHistoryDownloader would implicitely create one without arguments
+    from .config import Config
+    _ = Config(config_files=args.config)
+
+    from .twitterhistorydownloader import TwitterHistoryDownloader
     TwitterHistoryDownloader().download()
 
 
