@@ -30,6 +30,8 @@ import sqlalchemy.orm
 
 from .base import Base
 
+from ...integer_hash import integer_hash
+
 
 # https://developer.twitter.com/en/docs/twitter-api/data-dictionary/object-model/tweet
 
@@ -152,13 +154,13 @@ class Tweet(Base):
             "conservation_id",
         ]:
             try:
-                data[identifier] = cls.integer_hash(data[identifier])
+                data[identifier] = integer_hash(data[identifier])
             except KeyError:
                 pass
 
         if "referenced_tweets" in data:
             for i in range(len(data["referenced_tweets"])):
-                data["referenced_tweets"][i]["id"] = cls.integer_hash(
+                data["referenced_tweets"][i]["id"] = integer_hash(
                     data["referenced_tweets"][i]["id"]
                 )
 
