@@ -27,6 +27,7 @@ import datetime
 import json
 
 import requests
+import requests.exceptions
 
 
 class ApiResponseError(BaseException):
@@ -173,56 +174,60 @@ class TweetDownloader:  # pylint: disable=too-few-public-methods
             with self._api_key_manager.get_api_key() as api_key:
                 headers = {"Authorization": "Bearer {:s}".format(api_key)}
 
-                with requests.get(
-                    self.API_ENDPOINT_URL, headers=headers, params=query
-                ) as response:
+                try:
+                    response = requests.get(
+                        self.API_ENDPOINT_URL, headers=headers, params=query
+                    )
+                except requests.exceptions.RequestException:
+                    raise TemporaryApiResponseError(time_until_reset=120)
+
+                try:
+                    # some strings in Twitter API responses can apparently
+                    # contain NUL characters that cause hickups in PostgreSQL
+                    results = json.loads(
+                        response.text
+                        .replace("\\u0000", "\\u2400")
+                    )
+                except json.decoder.JSONDecodeError as exception:
+                    raise ApiResponseError(response.text) from exception
+
+                if not response.ok:
                     try:
-                        # some strings in Twitter API responses can apparently
-                        # contain NUL characters that cause hickups in PostgreSQL
-                        results = json.loads(
-                            response.text
-                            .replace("\\u0000", "\\u2400")
-                        )
-                    except json.decoder.JSONDecodeError as exception:
-                        raise ApiResponseError(response.text) from exception
+                        if results["error"]["code"] == 88:
+                            raise RateLimitExceededError(
+                                response.headers["x-rate-limit-reset"]
+                            )
+                    except KeyError:
+                        pass
 
-                    if not response.ok:
-                        try:
-                            if results["error"]["code"] == 88:
-                                raise RateLimitExceededError(
-                                    response.headers["x-rate-limit-reset"]
-                                )
-                        except KeyError:
-                            pass
+                    try:
+                        if (
+                                results["status"] == 429
+                                or results["status"] == 503
+                        ):
+                            # results["title"]: "Too Many Requests"
+                            # results["title"]: "Service Unavailable"
+                            # wait 2 min
+                            raise TemporaryApiResponseError(
+                                time_until_reset=120
+                            )
+                    except KeyError:
+                        pass
 
-                        try:
-                            if (
-                                    results["status"] == 429
-                                    or results["status"] == 503
-                            ):
-                                # results["title"]: "Too Many Requests"
-                                # results["title"]: "Service Unavailable"
-                                # wait 2 min
-                                raise TemporaryApiResponseError(
-                                    time_until_reset=120
-                                )
-                        except KeyError:
-                            pass
+                    try:
+                        if results["title"] == "UsageCapExceeded":
+                            raise MonthlyQuotaExceededError()
+                    except KeyError:
+                        pass
 
-                        try:
-                            if results["title"] == "UsageCapExceeded":
-                                raise MonthlyQuotaExceededError()
-                        except KeyError:
-                            pass
+                    try:
+                        if results["reason"] == "client-not-enrolled":
+                            raise NoAcademicTwitterAccount(results["detail"])
+                    except KeyError:
+                        pass
 
-                        try:
-                            if results["reason"] == "client-not-enrolled":
-                                raise NoAcademicTwitterAccount(results["detail"])
-                        except KeyError:
-                            pass
-
-                        # other, not anticipated error:
-                        raise ApiResponseError((results, response.headers))
+                    # other, not anticipated error:
+                    raise ApiResponseError((results, response.headers))
 
             yield results
 
